@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -9,16 +10,16 @@ func DiscordAPIToken() *config.Rule {
 	r := config.Rule{
 		Description: "Discord API key",
 		RuleID:      "discord-api-token",
-		Regex:       generateSemiGenericRegex([]string{"discord"}, hex64),
+		Regex:       generateSemiGenericRegex([]string{"discord"}, hex("64")),
 		SecretGroup: 1,
 		Keywords:    []string{"discord"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("discord", sampleHex64Token),
+		generateSampleSecret("discord", secrets.NewSecret(hex("64"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
 
 func DiscordClientID() *config.Rule {
@@ -26,16 +27,16 @@ func DiscordClientID() *config.Rule {
 	r := config.Rule{
 		Description: "Discord client ID",
 		RuleID:      "discord-client-id",
-		Regex:       generateSemiGenericRegex([]string{"discord"}, numeric18),
+		Regex:       generateSemiGenericRegex([]string{"discord"}, numeric("18")),
 		SecretGroup: 1,
 		Keywords:    []string{"discord"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("discord", sampleNumeric18),
+		generateSampleSecret("discord", secrets.NewSecret(numeric("18"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
 
 func DiscordClientSecret() *config.Rule {
@@ -43,14 +44,14 @@ func DiscordClientSecret() *config.Rule {
 	r := config.Rule{
 		Description: "Discord client secret",
 		RuleID:      "discord-client-secret",
-		Regex:       generateSemiGenericRegex([]string{"discord"}, extendedAlphaNumeric32),
+		Regex:       generateSemiGenericRegex([]string{"discord"}, alphaNumericExtended("32")),
 		SecretGroup: 1,
 		Keywords:    []string{"discord"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("discord", sampleExtendedAlphaNumeric32Token),
+		generateSampleSecret("discord", secrets.NewSecret(numeric("32"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
